@@ -1,7 +1,7 @@
 import itertools
 import warnings
 
-__all__=['translate', 'reverse_complement', 'count_coding_sites', 'count_coding_changes']
+__all__=['translate', 'reverse_complement', 'count_coding_sites', 'count_coding_changes', 'count_unique_changes']
 
 ##### reverse complement
 # thanks to Devon Ryan at https://bioinformatics.stackexchange.com/questions/3583/what-is-the-fastest-way-to-get-the-reverse-complement-of-a-dna-sequence-in-pytho
@@ -149,10 +149,11 @@ def count_coding_sites(cds, silent=False, cpg=False, nonsense=False):
     Returns
     -------
     counts : tuple of floats
-        With default options, counts contains:                  (nonsyn, syn)
-        If cpg is True (but nonsense is not), counts contains:  (nonsyn, syn, cpg_nonsyn, cpg_syn)
-        If nonsense is True (but cpg is not), counts contains:  (nonsyn, syn, nonsense)
-        If both cpg and nonsense are true, counts contains:     (nonsyn, syn, nonsense, cpg_nonsyn, cpg_syn, cpg_nonsense)
+
+        * With default options, counts contains:                  (nonsyn, syn)
+        * If cpg is True (but nonsense is not), counts contains:  (nonsyn, syn, cpg_nonsyn, cpg_syn)
+        * If nonsense is True (but cpg is not), counts contains:  (nonsyn, syn, nonsense)
+        * If both cpg and nonsense are true, counts contains:     (nonsyn, syn, nonsense, cpg_nonsyn, cpg_syn, cpg_nonsense)
 
     """   
     global codon2sitecount
@@ -257,11 +258,11 @@ def count_coding_changes(cds, cds2, silent=True, cpg=False, nonsense=False):
       Returns
       -------
       counts : tuple of ints
-          With default options, counts contains:                  (nonsyn, syn)
-          If cpg is True (but nonsense is not), counts contains:  (nonsyn, syn, cpg_nonsyn, cpg_syn)
-          If nonsense is True (but cpg is not), counts contains:  (nonsyn, syn, nonsense)
-          If both cpg and nonsense are true, counts contains:     (nonsyn, syn, nonsense, cpg_nonsyn, cpg_syn, cpg_nonsense)
 
+          * With default options, counts contains:                  (nonsyn, syn)
+          * If cpg is True (but nonsense is not), counts contains:  (nonsyn, syn, cpg_nonsyn, cpg_syn)
+          * If nonsense is True (but cpg is not), counts contains:  (nonsyn, syn, nonsense)
+          * If both cpg and nonsense are true, counts contains:     (nonsyn, syn, nonsense, cpg_nonsyn, cpg_syn, cpg_nonsense)
     """
     cds=cds.upper()
     cds2=cds2.upper()  
@@ -305,7 +306,7 @@ def count_coding_changes(cds, cds2, silent=True, cpg=False, nonsense=False):
         if codon!=codon2:
 
             if translate(codon)!=translate(codon2):          
-                if "*" in (transl(codon), transl(codon2)):
+                if "*" in (translate(codon), translate(codon2)):
                     is_nonsyn=2 #nonsense mutation
                 else:
                     is_nonsyn=1
@@ -344,30 +345,31 @@ def count_coding_changes(cds, cds2, silent=True, cpg=False, nonsense=False):
 def count_unique_changes(cds, other_cds_list, silent=True, cpg=False, nonsense=False):
     """ Counts the number of unique synonymous and non-synonymous changes between one reference CDS sequence and a set of others.
 
-         This function is instrumental for any dN/dS analysis.
-         Sequences should be aligned using gaps "-". Gapped positions are not counted.
-         Codons with any character different from ACTG (for example, N) are skipped and a message is printed to stderr.
-         If the same mutation is observed between cds and multiple sequences in other_cds_list, it is counted only once.
+     This function is instrumental for any dN/dS analysis.
+     Sequences should be aligned using gaps "-". Gapped positions are not counted.
+     Codons with any character different from ACTG (for example, N) are skipped and a message is printed to stderr.
+     If the same mutation is observed between cds and multiple sequences in other_cds_list, it is counted only once.
 
-        silent : bool, defaults to True
-            do not print warning messages for non-ATGC characters
+    silent : bool, defaults to True
+        do not print warning messages for non-ATGC characters
 
-        cpg : bool
-            if True, separate counts for CpG sites only are provided, altering the structure of the returned tuple (see below).
-            Note that only cds is inspected to identity CpG sites, so with cpg=True the output may be different for (cds, cds2) and (cds2, cds)
-            Note that the total counts are still provided. To obtain the number of nonCpG changes, subtract the number of CpG sites from the total number
+    cpg : bool
+        if True, separate counts for CpG sites only are provided, altering the structure of the returned tuple (see below).
+        Note that only cds is inspected to identity CpG sites, so with cpg=True the output may be different for (cds, cds2) and (cds2, cds)
+        Note that the total counts are still provided. To obtain the number of nonCpG changes, subtract the number of CpG sites from the total number
 
-        nonsense : bool
-            if True, non-sense mutations (i.e. stop codons or mutations to a stop codon) are not counted as non-synonymous, and are returned separately, 
-            altering the structure of the returned tuple (see below).
+    nonsense : bool
+        if True, non-sense mutations (i.e. stop codons or mutations to a stop codon) are not counted as non-synonymous, and are returned separately, 
+        altering the structure of the returned tuple (see below).
 
-        Returns
-        -------
-        counts : tuple of ints
-            With default options, counts contains:                  (nonsyn, syn)
-            If cpg is True (but nonsense is not), counts contains:  (nonsyn, syn, cpg_nonsyn, cpg_syn)
-            If nonsense is True (but cpg is not), counts contains:  (nonsyn, syn, nonsense)
-            If both cpg and nonsense are true, counts contains:     (nonsyn, syn, nonsense, cpg_nonsyn, cpg_syn, cpg_nonsense)
+    Returns
+    -------
+    counts : tuple of ints
+
+        * With default options, counts contains:                  (nonsyn, syn)
+        * If cpg is True (but nonsense is not), counts contains:  (nonsyn, syn, cpg_nonsyn, cpg_syn)
+        * If nonsense is True (but cpg is not), counts contains:  (nonsyn, syn, nonsense)
+        * If both cpg and nonsense are true, counts contains:     (nonsyn, syn, nonsense, cpg_nonsyn, cpg_syn, cpg_nonsense)
     """
     cds=cds.upper()
     position_to_change={}  ### hash keeping track of changes we already saw   k: position (0based) -> list of other nts observed in any of other_cds
@@ -413,7 +415,7 @@ def count_unique_changes(cds, other_cds_list, silent=True, cpg=False, nonsense=F
             if codon!=codon2:
 
                 if translate(codon)!=translate(codon2):          
-                    if "*" in (transl(codon), transl(codon2)):
+                    if "*" in (translate(codon), translate(codon2)):
                         is_nonsyn=2 #nonsense mutation
                     else:
                         is_nonsyn=1
